@@ -12,11 +12,11 @@ from django.conf import settings
 
 def run_makemessages(verbosity=0):
 	#TODO: allow passing arguments to makemessages - ignore languages, obsolete, location, domain atc.
-	#if isinstance(settings.LANGUAGES,(list,tuple)):
-	#	language_codes = [language_item[0] for language_item in settings.LANGUAGES]
-	#	management.call_command('makemessages', locale=language_codes, symlinks=True, verbosity=verbosity)
-	#else:
-	management.call_command('makemessages', all=True, symlinks=True, verbosity=verbosity)
+	if isinstance(settings.LANGUAGES,(list,tuple)):
+		language_codes = [language_item[0] for language_item in settings.LANGUAGES]
+		management.call_command('makemessages', locale=language_codes, symlinks=True, verbosity=verbosity)
+	else:
+		print "Missing settings.LANGUAGES"
 	pass
 
 def run_compilemessages(verbosity=0):
@@ -34,7 +34,7 @@ def run_compilemessages(verbosity=0):
 	OneSky's simple python wrapper
 	
 	Known WTF?:
-	- If you manualy create project file (django.po) inside SkyOne app, API will return 400 error "This file is not downloadable through API"
+	- If you manualy create project file (e.g. django.po) inside SkyOne app, API will return 400 error "This file is not downloadable through API"
 	- Always upload at least your default django.po language file for each project. 
 	
 """
@@ -204,4 +204,4 @@ class Command(management.base.BaseCommand):
 		except OneSkyApiClientException,e:
 			print e
 			
-		pass
\ No newline at end of file
+		pass
